@@ -1537,6 +1537,18 @@ void GraphModifier::setFloorLevel(int value)
 {
     m_graph->setFloorLevel(float(value));
     qDebug() << "Floor level:" << value;
+
+    //adjust camera min max
+    if (value == 0) {
+        m_graph->setMinCameraYRotation(-90);
+        m_graph->setMaxCameraYRotation(90);
+    } else if (value > 0) {
+        m_graph->setMinCameraYRotation(-90);
+        m_graph->setMaxCameraYRotation(0);
+    } else {
+        m_graph->setMinCameraYRotation(0);
+        m_graph->setMaxCameraYRotation(90);
+    }
 }
 
 void GraphModifier::setGraphMargin(int value)
